### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
### Composite linkage disequlibrum calculation.
###

.cld <- function(data, width = 5)
{
    nsub <- nrow(data)
    nsnp <- ncol(data)
    if (width > nsnp)
        stop("Width must be less than the number of snps.")
    delta <- rep.int(0, (nsnp-width)*width)
    res <- .C("composite_linkage_disequilibrium",
              snp = as.raw(data),
              n_sub = as.integer(nsub),
              n_snp = as.integer(nsnp),
              width = as.integer(width),
              delta = as.double(delta), PACKAGE="StudentGWAS")
    matrix(res$delta, nrow=(nsnp-width), ncol=width, byrow=TRUE,
           dimnames = list(colnames(data)[1:(nsnp-width)], NULL)) 
}

setGeneric("cld", signature="x",
    function(x, first, last, width = 5) standardGeneric("cld")
)

setMethod("cld", "GWASdata",
    function(x, first, last, width = 5) 
    {
        data <- getCols(x, first, last)
        colnames(data) <- getSnps(metadatapath(x))$snp_id[first:last] 
        .cld(data, width = width)
    }
)

