\name{cld}
\alias{cld,GWASdata-method}
\alias{cld}

\title{cld}

\description{
  Generic function that performs a composite linkage 
  disequilibrium calculation. 
} 


\usage{
  cld(x, first, last, width = 5)
  \S4method{cld}{GWASdata}(x, first, last, width = 5)
}

\arguments{
  \item{x}{\code{GWASdata} object.} 
  \item{first}{Integer specifying the first column of data.} 
  \item{last}{Integer specifying the last column of data.} 
  \item{width}{Integer value indicating the number of neighboring snps 
   to be used in the linkage disequlibrium calculation.}
}

\details{
  Composite linkage disequilibrium is a statistical measure of association across 
  loci, when haplotype phase is not known. See Weir and Cockerham, 1989; 
  Weir 1996 pp. 94, 125. 

  \deqn{Delta = n / N - 2 p_{A_1} p_{B_1}}

   where
 
   N: number of subjects
   \eqn{p_{A_1}}: frequency of allele \eqn{A_1} at snp \eqn{A}

   \eqn{p_{B_1}}: frequency of an allele \eqn{B_1} at snp \eqn{B}

   \eqn{n: 2 X_{A_1A_1, B_1B_1} + X_{A_1A_1, B_1B_2} +
       X_{A_1A_2, B_1B_1} + (1/2) X_{A_1A_2, B_1B_2}}

  The number of linkage disequilibrium 
  comparisions made are (# of snps - width)*width and therefore 
  the number of snps returned is (# of snps - width). In the matrix
  of values returend, each row represents a snp and each column is a 
  single linkage disequilibrium comparision between that snp and one of its
  neighbors. The number of snp-snp comparisions is defined by the \code{width}
  argument and the order of comparisions is from left to right across
  the data columns. 

}

\value{
  A matrix of linkage disequilibrium values where the rows are snps and columns are
  the positions of neighboring snps the length of the \code{width} argument. 
  The number of snps returned is (\# of snps - width). 
}

\author{Student Name}

\references{
   WEIR, B., 1996 \emph{Genetic Data Analysis II}. Sinauer Associates,
   Sunderland, MA.

   WEIR, B. S., and C. C. COCKERHAM, 1989 \emph{Complete characterization of
   disequilibrium at two loci}, pp. 86 - 110 in Mathematical Evolutionary
   Theory, edited by M. W. FELDMAN. Princeton University Press,
   Princeton, NJ.
}

\seealso{
  \link{GWASdata-class} for the \code{GWASdata} class.
}

\examples{
dataPath <- system.file("extdata", "small_snpData.nc",
                        package="StudentGWAS")
metadataPath <- system.file("extdata", "small_metadata.sqlite",
                            package="StudentGWAS")
data <- GWASdata(dataPath, metadataPath)
res <- cld(data, first=1, last=15, width=3)
}

\keyword{methods}
