\name{.fapply}
\alias{.fapply}
\title{

  Accumulate the results of applying a function to a stream of data, as
  from a file.

}
\description{
  
  This function iterates over a stream of data, mapping a \sQuote{chunk}
  of the stream from one represetion to another (e.g., counting the
  number of heterozygous individuals at each locus) and reducing the the
  transformed representations to a final answer.

}

\arguments{

  \item{con}{
    
    An open \link{connection} or similar instance, to be passed to
    \code{.get} argument and used to retrieve the next chunk of data.

  }

  \item{FUN}{
    
    A function accepting one or more objects, the first of which is the
    current chunk of data returned by \code{.get}.

  }

  \item{\dots}{

    Additional arguments, passed to \code{FUN}.

  }

  \item{.get}{

    A function of one argument, \code{con}, representing the current
    state of the stream. The function should read a chunk of data,
    returning it as a matrix and leaving \code{con} in a condition such
    that the next chunk of data can be accessed. If the last chunk of
    data has been input, \code{.get} should return a matrix with 0 rows.

  }

  \item{.reduce}{

    A function of one argument, representing the list of results
    returned by \code{FUN}, one for each chunk of data in the
    stream. \code{.reduce} should transform this list into the final
    data format.

  }
}

\value{

  The value returned from \code{.fapply} is the value returned by
  \code{.reduce}.

}

\author{Martin Morgan \url{mailto:mtmorgan@fhcrc.org}}

\examples{
datapath <- system.file("extdata", "small_snpData.nc",
                        package="StudentGWAS")
metadatapath <- system.file("extdata", "small_metadata.sqlite",
                            package="StudentGWAS")
gwas <- GWASdata(datapath, metadatapath)

hetero <- function(x)
    ## 'FUN' applied to each chunk
    colSums(x==2) / nrow(x)

makeGet <- function()
{
    ## tricky -- create function with 'state' remembered across calls
    snpsPerChunk <- 5
    prev <- 0
    function(gwas) {
        n <- min(snpsPerChunk, ncol(gwas) - prev)
        if (n < 1) return(matrix(0, 0, 0))
        x <- getCols(gwas, prev + 1, prev + n)
        prev <<- prev + n
        x
    }
}

.reduce <- function(lst)
    unlist(lst)

res0 <- StudentGWAS:::.fapply(gwas, hetero, .get=makeGet(),
                              .reduce=.reduce)
res1 <- colSums(getCols(gwas, 1, ncol(gwas)) == 2) / nrow(gwas)
stopifnot(identical(res0, res1))


}

\keyword{ manip }
